From mboxrd@z Thu Jan  1 00:00:00 1970
From: Michael Forney <mforney@mforney.org>
To: list+catgirl@causal.agency
Subject: [PATCH] Avoid writing past the end of the status bar
Date: Fri,  4 Jun 2021 22:14:44 -0700
Message-Id: <20210605051444.28401-1-mforney@mforney.org>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

When waddnstr is called with a string that would extend past the
end of the window, the string is truncated, the cursor remains at
the last column, and ERR is returned. If this error is ignored and
the loop continues, the next call to waddnstr overwrites the character
at this column, resulting in a slight visual artifact. When the
window is too small to fit the full status line, it is effectively
truncated by one space on the right, since the string shown for
each channel begins with a space.  Additionally, if the last window
is the current window, the space is shown with a colored background.

To fix this, when waddnstr returns ERR, exit the loop in styleAdd()
early return -1 to propogate this error down to the caller.
---
 ui.c | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/ui.c b/ui.c
index 6449e27..e270f5e 100644
--- a/ui.c
+++ b/ui.c
@@ -374,14 +374,16 @@ static short stylePair(struct Style style) {
 	return colorPair(Colors[style.fg], Colors[style.bg]);
 }
 
-static void styleAdd(WINDOW *win, const char *str) {
+static int styleAdd(WINDOW *win, const char *str) {
 	struct Style style = StyleDefault;
 	while (*str) {
 		size_t len = styleParse(&style, &str);
 		wattr_set(win, styleAttr(style), stylePair(style), NULL);
-		waddnstr(win, str, len);
+		if (waddnstr(win, str, len) == ERR)
+			return -1;
 		str += len;
 	}
+	return 0;
 }
 
 static void statusUpdate(void) {
@@ -420,7 +422,8 @@ static void statusUpdate(void) {
 		if (window->scroll) {
 			catf(&cat, "~%d ", window->scroll);
 		}
-		styleAdd(status, buf);
+		if (styleAdd(status, buf))
+			break;
 	}
 	wclrtoeol(status);
 
-- 
2.31.1


From mboxrd@z Thu Jan  1 00:00:00 1970
Content-Type: text/plain;
	charset=us-ascii
Mime-Version: 1.0 (Mac OS X Mail 13.4 \(3608.120.23.2.7\))
Subject: Re: [PATCH] Avoid writing past the end of the status bar
From: june <june@causal.agency>
In-Reply-To: <20210605051444.28401-1-mforney@mforney.org>
Date: Sat, 5 Jun 2021 13:23:41 -0400
Cc: list+catgirl@causal.agency
Content-Transfer-Encoding: 7bit
Message-Id: <1E52DF4C-ABEE-480A-A317-1AF6FEF6AC82@causal.agency>
References: <20210605051444.28401-1-mforney@mforney.org>
To: Michael Forney <mforney@mforney.org>

Thanks, applied.

